==> oci-2.23.4.tar.gz: oci-2.23.4/src/oci/log_analytics/models/upsert_log_analytics_association_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpsertLogAnalyticsAssociationDetails(object):
    """
    UpsertLogAnalyticsAssociationDetails
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpsertLogAnalyticsAssociationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this UpsertLogAnalyticsAssociationDetails.
        :type compartment_id: str

        :param items:
            The value to assign to the items property of this UpsertLogAnalyticsAssociationDetails.
        :type items: list[UpsertLogAnalyticsAssociation]

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'items': 'list[UpsertLogAnalyticsAssociation]'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'items': 'items'
        }

        self._compartment_id = None
        self._items = None

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this UpsertLogAnalyticsAssociationDetails.
        compartmentId


        :return: The compartment_id of this UpsertLogAnalyticsAssociationDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this UpsertLogAnalyticsAssociationDetails.
        compartmentId


        :param compartment_id: The compartment_id of this UpsertLogAnalyticsAssociationDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def items(self):
        """
        Gets the items of this UpsertLogAnalyticsAssociationDetails.
        list of rule entity association details


        :return: The items of this UpsertLogAnalyticsAssociationDetails.
        :rtype: list[UpsertLogAnalyticsAssociation]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this UpsertLogAnalyticsAssociationDetails.
        list of rule entity association details


        :param items: The items of this UpsertLogAnalyticsAssociationDetails.
        :type: list[UpsertLogAnalyticsAssociation]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other

==> oci-2.44.1.tar.gz: oci-2.44.1/src/oci/log_analytics/models/upsert_log_analytics_association_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpsertLogAnalyticsAssociationDetails(object):
    """
    The required information to update or create a list of associations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpsertLogAnalyticsAssociationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this UpsertLogAnalyticsAssociationDetails.
        :type compartment_id: str

        :param items:
            The value to assign to the items property of this UpsertLogAnalyticsAssociationDetails.
        :type items: list[oci.log_analytics.models.UpsertLogAnalyticsAssociation]

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'items': 'list[UpsertLogAnalyticsAssociation]'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'items': 'items'
        }

        self._compartment_id = None
        self._items = None

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this UpsertLogAnalyticsAssociationDetails.
        The compartment ID


        :return: The compartment_id of this UpsertLogAnalyticsAssociationDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this UpsertLogAnalyticsAssociationDetails.
        The compartment ID


        :param compartment_id: The compartment_id of this UpsertLogAnalyticsAssociationDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def items(self):
        """
        Gets the items of this UpsertLogAnalyticsAssociationDetails.
        The information required to create or update an association.


        :return: The items of this UpsertLogAnalyticsAssociationDetails.
        :rtype: list[oci.log_analytics.models.UpsertLogAnalyticsAssociation]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this UpsertLogAnalyticsAssociationDetails.
        The information required to create or update an association.


        :param items: The items of this UpsertLogAnalyticsAssociationDetails.
        :type: list[oci.log_analytics.models.UpsertLogAnalyticsAssociation]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
